about summary refs log tree commit diff
path: root/src/libtest
diff options
context:
space:
mode:
authorJethro Beekman <jethro@fortanix.com>2018-08-27 21:33:26 -0700
committerJethro Beekman <jethro@fortanix.com>2018-12-07 11:26:50 +0530
commit4a3505682e97c8e667338056ae216e4b84b22dd7 (patch)
tree64f04641da2097afb5c6a386f8e26a36a2687e6e /src/libtest
parentc559216ad0d2f0737f8dbb51a7d42b1727b77b3c (diff)
Add x86_64-fortanix-unknown-sgx target to libstd and dependencies
The files src/libstd/sys/sgx/*.rs are mostly copied/adapted from
the wasm target.

This also updates the dlmalloc submodule to the very latest version.
Diffstat (limited to 'src/libtest')
-rw-r--r--src/libtest/lib.rs10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/libtest/lib.rs b/src/libtest/lib.rs
index 7c26d042a7c..b8711a69147 100644
--- a/src/libtest/lib.rs
+++ b/src/libtest/lib.rs
@@ -1018,10 +1018,12 @@ fn use_color(opts: &TestOpts) -> bool {
     }
 }
 
-#[cfg(any(target_os = "cloudabi", target_os = "redox",
-          all(target_arch = "wasm32", not(target_os = "emscripten"))))]
+#[cfg(any(target_os = "cloudabi",
+          target_os = "redox",
+          all(target_arch = "wasm32", not(target_os = "emscripten")),
+          target_env = "sgx"))]
 fn stdout_isatty() -> bool {
     // FIXME: Implement isatty on Redox
     false
 }
 #[cfg(unix)]
@@ -1246,7 +1248,7 @@ fn get_concurrency() -> usize {
         1
     }
 
-    #[cfg(all(target_arch = "wasm32", not(target_os = "emscripten")))]
+    #[cfg(any(all(target_arch = "wasm32", not(target_os = "emscripten")), target_env = "sgx"))]
     fn num_cpus() -> usize {
         1
     }
@@ -1018,10 +1018,12 @@ fn use_color(opts: &TestOpts) -> bool {
 fn stdout_isatty() -> bool {
-    // FIXME: Implement isatty on Redox
+    // FIXME: Implement isatty on Redox and SGX
     false
 }